@@ -1,3 +1,3 @@
 from .errors import *
-from .genshinstats import *
-from .pretty import *
\ No newline at end of file
+from .gachalog import *
+from .genshinstats import *
\ No newline at end of file
